embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Atbfunnel

Struct Atbfunnel 

pub struct Atbfunnel { /* private fields */ }
ATB funnel module 0

Implementations

Source

impl Atbfunnel

pub const unsafe fn from_ptr(ptr: *mut ()) -> Atbfunnel

pub const fn as_ptr(&self) -> *mut ()

pub const fn ctrlreg(self) -> Reg<Ctrlreg, RW>

The IDFILTER0 register enables the programming of ID filtering for master port 0.

pub const fn priorityctrlreg(self) -> Reg<Priorityctrlreg, RW>

The Priority_Ctrl_Reg register defines the order in which inputs are selected. Each 3-bit field is a priority for each particular slave interface.

pub const fn itatbdata0(self) -> Reg<Itatbdata0, RW>

The ITATBDATA0 register performs different functions depending on whether the access is a read or a write.

pub const fn itatbctr2(self) -> Reg<Itatbctr2, RW>

The ITATBCTR2 register performs different functions depending on whether the access is a read or a write.

pub const fn itatbctr1(self) -> Reg<Itatbctr1, RW>

The ITATBCTR1 register performs different functions depending on whether the access is a read or a write.

pub const fn itatbctr0(self) -> Reg<Itatbctr0, RW>

The ITATBCTR0 register performs different functions depending on whether the access is a read or a write.

pub const fn itctrl(self) -> Reg<Itctrl, RW>

The ITCTRL register enables the component to switch from a functional mode, which is the default behavior, to integration mode where the inputs and outputs of the component can be directly controlled for the purposes of integration testing and topology detection.

pub const fn claimset(self) -> Reg<Claimset, RW>

Software can use the claim tag to coordinate application and debugger access to trace unit functionality. The claim tags have no effect on the operation of the component. The CLAIMSET register sets bits in the claim tag, and determines the number of claim bits implemented.

pub const fn claimclr(self) -> Reg<Claimclr, RW>

Software can use the claim tag to coordinate application and debugger access to trace unit functionality. The claim tags have no effect on the operation of the component. The CLAIMCLR register sets the bits in the claim tag to 0 and determines the current value of the claim tag.

pub const fn lar(self) -> Reg<Lar, RW>

This is used to enable write access to device registers.

pub const fn lsr(self) -> Reg<Lsr, RW>

This indicates the status of the lock control mechanism. This lock prevents accidental writes by code under debug. Accesses to the extended stimulus port registers are not affected by the lock mechanism. This register must always be present although there might not be any lock access control mechanism. The lock mechanism, where present and locked, must block write accesses to any control register, except the Lock Access Register. For most components this covers all registers except for the Lock Access Register.

pub const fn authstatus(self) -> Reg<Authstatus, RW>

Indicates the current level of tracing permitted by the system

pub const fn devid(self) -> Reg<Devid, R>

Indicates the capabilities of the component.

pub const fn devtype(self) -> Reg<Devtype, R>

The DEVTYPE register provides a debugger with information about the component when the Part Number field is not recognized. The debugger can then report this information.

pub const fn pidr4(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_0(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_1(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_2(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_3(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn cidr_0(self) -> Reg<u32, RW>

Coresight component identification registers.

pub const fn cidr_1(self) -> Reg<u32, RW>

Coresight component identification registers.

pub const fn cidr_2(self) -> Reg<u32, RW>

Coresight component identification registers.

pub const fn cidr_3(self) -> Reg<u32, RW>

Coresight component identification registers.